# Drp User Management

A laravel 5.4 package to handle user management

- Basic user permission levels
- Admin panel to manage users
- First time login account setup functionality

## Getting Started


### Prerequisites


```
Laravel 5.4 application
```

### Installing


Add the Drp composer repository to your composer file, this will allow you to pull in our internal packages.



```
"repositories": [
    {
      "type": "composer",
      "url": "https://composer.drp.digital"
    }
  ],
```

You can then install this package via composer using this command:

```
composer require drp/user-management:dev-master
```


Next, you must install the service provider:

```
// config/app.php
'providers' => [
    ...
    Drp\UserManagement\UserManagementServiceProvider::class,
];
```


Next publish the resources. If you have already ran ```make:auth()``` or have an existing migration called ```CreateUsersTable``` you will have to delete this migration before running the command or it will not publish the migration.

```
php artisan vendor:publish --provider="Drp\UserManagement\UserManagementServiceProvider" 
```


After the migration has been published you can create the users table by running the migrations:

```
php artisan migrate
```

## Features

- Manage user and their permission groups
- Send new users a 1 use expiring login link. New users will then have to setup thier own password
- Re-send 1st time login links
- Set new registration to require approval
- Basic policy for `Manage`, `Delete` and `changeRole`


### Setup 

If you want to use the default email notification you will need to hook up the event handlers. Add the following to your `EventServiceProvider`

##### Events 
```
protected $listen = [
        \Drp\UserManagement\Events\AccountActivated::class => 
        [
            \Drp\UserManagement\Mail\AccountActivation::class,
        ],
        \Drp\UserManagement\Events\UserCreatedWithLoginCode::class => 
        [
            \Drp\UserManagement\Mail\FirstTimeAccountSetup::class,
        ]
    ]
```
##### Middleware 

 Add middleware `setupComplete` to any admin routes or add it to the middleware stack

##### Config 

The package config file will allow certain options to be confgiured. Some defaults have been set but here is an overview of the options:

```
    'model' => Drp\UserManagement\User::class,
```

The User model your application uses. You will either need to extend this model or use the `ManagedUser`  interface


```
    'layout' => 'userManagement::layout',

    'layout-admin' => 'userManagement::layout',
```

These are the templates used in the view, set the to be whatver the template for your admin is i.e `layouts.admin` or `AdminLte::page`

```
    'middleware' => 'web',
```

This is the middleware(s)  that are added to the user management admin routes

```
    'roles' => [
        'Super Administrator',
        'Administrator',
        'User',
    ],

    'super_admin_roles' => [
        'Super Administrator',
    ],

    'admin_roles' => [
        'Administrator',
        'Super Administrator',
    ],
```

These are you admin groups you can add as many roles as you like.

```
    'login_token_expiry_days' => 7,
```

the length of time the initial log token is valid for when a new user is created


```
    'requires_approval' => false

```

This option is used if your front end user (registrations) will require pre-apporval by an admin before they can get access. If this is `false` all users are marked as `approved` on creation.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 


## TODO

- Send notification on requires approval

