<?php

namespace Drp\UserManagement\Mail;

use Drp\UserManagement\Events\UserCreatedWithLoginCode;
use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\Mail;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class FirstTimeAccountSetup extends Mailable
{
    use Queueable, SerializesModels;

    /**
     * @var string
     */
    public $expiry;
    /**
     * @var null
     */
    public $token;

    /**
     * FirstTimeAccountSetup constructor.
     * @param null|string $expiry
     * @param null|string $token
     */
    public function __construct($expiry = null, $token = null)
    {
        $this->expiry = $expiry;
        $this->token = $token;
    }


    /**
     * Handle the event here
     * @param UserCreatedWithLoginCode $event
     * @return void
     */
    public function handle(UserCreatedWithLoginCode $event)
    {
        Mail::to($event->user)->send(
            new static(
                $event->user->loginExpiry()->format('jS F Y H:i'),
                $event->user->loginToken()
            )
        );
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        return $this
            ->subject(config('app.name') . ': Account setup')
            ->markdown('userManagement::emails.account.setup');
    }
}
